@@ -1,3 +1,4 @@
+mod apps;
 mod bots;
 mod chat;
 mod conversations;
@@ -8,6 +9,7 @@ mod users;
 mod views;
 mod webhook;
 
+pub use apps::*;
 pub use bots::*;
 pub use chat::*;
 pub use conversations::*;
